
<!--
FrozenIsBool False
-->

#Noder

##Doc
----


> 
> A Noder defines Child ordered dicts with <DoStr> as KeyStr. 
> The items inside are automatically setted with Noded<DoStr><TypeStr> and have 
> a Pointer to the parent InstanceVariable. This is the beginning for buiding high
> arborescent and (possibly circular) structures of objects.
> 
> 

----

<small>
View the Noder notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Noder.ipynb)
</small>

